==> luna3-2.13.60.tar.gz: luna3-2.13.60/luna3/public/sdk.py <==
"""
Module contains backward compatible match objects for luna-remote-sdk
"""
from dataclasses import dataclass
from typing import Dict, List, Optional

from luna3.common.http_objs import BoundingBox, FaceQuality
from luna3.events.http_objs import BaseClass
from luna3.public.common import PeopleCount


@dataclass
class LivenessParams(BaseClass):
    """Liveness settings"""

    qualityThreshold: Optional[float] = None
    scoreThreshold: Optional[float] = None


@dataclass
class DeepfakeParams(BaseClass):
    """Deepfake settings"""

    realThreshold: float = None
    mode: Optional[int] = None


@dataclass
class EstimatorsParams(BaseClass):
    """Estimation parameters"""

    livenessParams: LivenessParams = None
    faceDescriptorVersion: Optional[int] = None
    bodyDescriptorVersion: Optional[int] = None
    deepfakeParams: DeepfakeParams = None


@dataclass
class Image(BaseClass):
    """Image for estimation"""

    body: bytes
    filename: str
    imageType: Optional[int] = 0
    faceDetections: Optional[List[BoundingBox]] = None
    bodyDetections: Optional[List[BoundingBox]] = None

    def asDict(self):
        image = super().asDict()
        if self.faceDetections:
            image["face_detections"] = [detection.asDict() for detection in self.faceDetections]
        if self.bodyDetections:
            image["body_detections"] = [detection.asDict() for detection in self.bodyDetections]
        return image


@dataclass
class FaceDetectionFilters(BaseClass):
    """Filters for face detection"""

    yawThreshold: Optional[float] = None
    pitchThreshold: Optional[float] = None
    rollThreshold: Optional[float] = None
    livenessStates: Optional[List[int]] = None
    maskStates: Optional[List[int]] = None
    scoreThreshold: Optional[float] = None
    deepfakeStates: Optional[List[int]] = None


@dataclass
class Filters(BaseClass):
    """Estimation filters"""

    faceDetectionFilters: FaceDetectionFilters


@dataclass
class Targets(BaseClass):
    """Estimation targets"""

    exif: int = None
    peopleCount: PeopleCount = None
    faceDetection: int = None
    faceWarp: int = None
    faceLandmarks5: int = None
    faceLandmarks68: int = None
    gaze: int = None
    headPose: int = None
    eyes: int = None
    mouthAttributes: int = None
    faceWarpQuality: int = None
    emotions: int = None
    faceDescriptor: int = None
    basicAttributes: int = None
    mask: int = None
    glasses: int = None
    liveness: int = None
    bodyWarp: int = None
    bodyDetection: int = None
    bodyDescriptor: int = None
    bodyAttributes: int = None
    upperBody: int = None
    accessories: int = None
    lowerBody: int = None
    faceQuality: FaceQuality = None
    deepfake: int = None

    def asDict(self) -> Dict:
        """
        Recursively cast class to dict.

        Returns:
            self as dict without empty fields
        """
        res = super().asDict()
        if peopleCount := res.get("people_count"):
            res["people_count"] = peopleCount.asDict()
        if faceQuality := res.get("face_quality"):
            res["face_quality"] = faceQuality.asDict()
        return res


@dataclass
class Params(BaseClass):
    """Parameters for performing estimation request"""

    targets: Targets
    useExifInfo: Optional[int] = None
    filters: Optional[Filters] = None
    estimatorsParams: Optional[EstimatorsParams] = None
    aggregate: Optional[int] = None
    multifacePolicy: Optional[int] = None


@dataclass
class Estimator(BaseClass):
    """Estimator request schema"""

    params: Params
    images: List[Image]

==> luna3-2.13.71.tar.gz: luna3-2.13.71/luna3/public/sdk.py <==
"""
Module contains backward compatible match objects for luna-remote-sdk
"""
from dataclasses import dataclass

from luna3.common.http_objs import BoundingBox, FaceQuality
from luna3.events.http_objs import BaseClass
from luna3.public.common import PeopleCount


@dataclass
class LivenessParams(BaseClass):
    """Liveness settings"""

    qualityThreshold: float | None = None
    scoreThreshold: float | None = None


@dataclass
class DeepfakeParams(BaseClass):
    """Deepfake settings"""

    realThreshold: float = None
    mode: int | None = None


@dataclass
class EstimatorsParams(BaseClass):
    """Estimation parameters"""

    livenessParams: LivenessParams = None
    faceDescriptorVersion: int | None = None
    bodyDescriptorVersion: int | None = None
    deepfakeParams: DeepfakeParams = None


@dataclass
class Image(BaseClass):
    """Image for estimation"""

    body: bytes
    filename: str
    imageType: int | None = 0
    faceDetections: list[BoundingBox] | None = None
    bodyDetections: list[BoundingBox] | None = None

    def asDict(self):
        image = super().asDict()
        if self.faceDetections:
            image["face_detections"] = [detection.asDict() for detection in self.faceDetections]
        if self.bodyDetections:
            image["body_detections"] = [detection.asDict() for detection in self.bodyDetections]
        return image


@dataclass
class FaceDetectionFilters(BaseClass):
    """Filters for face detection"""

    yawThreshold: float | None = None
    pitchThreshold: float | None = None
    rollThreshold: float | None = None
    livenessStates: list[int] | None = None
    maskStates: list[int] | None = None
    scoreThreshold: float | None = None
    deepfakeStates: list[int] | None = None


@dataclass
class Filters(BaseClass):
    """Estimation filters"""

    faceDetectionFilters: FaceDetectionFilters


@dataclass
class Targets(BaseClass):
    """Estimation targets"""

    exif: int = None
    peopleCount: PeopleCount = None
    faceDetection: int = None
    faceWarp: int = None
    faceLandmarks5: int = None
    faceLandmarks68: int = None
    gaze: int = None
    headPose: int = None
    eyes: int = None
    mouthAttributes: int = None
    faceWarpQuality: int = None
    emotions: int = None
    faceDescriptor: int = None
    basicAttributes: int = None
    mask: int = None
    glasses: int = None
    liveness: int = None
    bodyWarp: int = None
    bodyDetection: int = None
    bodyDescriptor: int = None
    bodyAttributes: int = None
    upperBody: int = None
    accessories: int = None
    lowerBody: int = None
    faceQuality: FaceQuality = None
    deepfake: int = None

    def asDict(self) -> dict:
        """
        Recursively cast class to dict.

        Returns:
            self as dict without empty fields
        """
        res = super().asDict()
        if peopleCount := res.get("people_count"):
            res["people_count"] = peopleCount.asDict()
        if faceQuality := res.get("face_quality"):
            res["face_quality"] = faceQuality.asDict()
        return res


@dataclass
class Params(BaseClass):
    """Parameters for performing estimation request"""

    targets: Targets
    useExifInfo: int | None = None
    filters: Filters | None = None
    estimatorsParams: EstimatorsParams | None = None
    aggregate: int | None = None
    multifacePolicy: int | None = None


@dataclass
class Estimator(BaseClass):
    """Estimator request schema"""

    params: Params
    images: list[Image]
